@@ -2,11 +2,14 @@
 # Copyright 2022, Board of Regents of the University of Wisconsin System
 # SPDX-License-Identifier: MIT
 
-from ._api import java_env, java_home
+from ._api import cache_file, cache_jdk, cache_package, java_env, java_home
 from ._version import __version__
 
 __all__ = [
     "__version__",
+    "cache_jdk",
     "java_env",
     "java_home",
+    "cache_file",
+    "cache_package",
 ]
